/** 
 * Title:        EnglishAuction
 * Description:  Loklne rozhranie pre EnglishAuction entity bean
 */ 
 
import java.sql.Timestamp; 
import javax.ejb.EJBLocalObject; 

public interface EnglishAuction extends EJBLocalObject {
 
  public Integer getId(); 

  public void setName(String newName); 
  public String getName(); 
  
  public void setDescription(String newDescription); 
  public String getDescription(); 
  
  public void setStatus(String newStatus) throws InvalidAuctionStatusException; 
  public String getStatus(); 
  
  public void setStartingBid(Double newStartingBid) 
                                          throws InvalidAuctionStatusException; 
  public Double getStartingBid(); 
  
  public void setMinBidIncrement(Double newMinBidIncrement) 
                                          throws InvalidAuctionStatusException; 
  public Double getMinBidIncrement(); 
  
  public void setReserveAmount(Double newReserveAmount) 
                                          throws InvalidAuctionStatusException; 
  public Double getReserveAmount(); 
  
  public void setStartDateTime(Timestamp newStartDateTime) 
                                          throws InvalidAuctionStatusException; 
  public Timestamp getStartDateTime(); 
  
  public void setScheduledEndDateTime(Timestamp newScheduledEndDateTime) 
                                          throws InvalidAuctionStatusException; 
  public Timestamp getScheduledEndDateTime(); 
  
  public void setActualEndDateTime(Timestamp newActualEndDateTime); 
  public Timestamp getActualEndDateTime(); 
  
  public void assignItem(Item newItem, int newQuantity) 
                                          throws InvalidAuctionStatusException; 
  public Item getItem(); 
  
  public Integer getQuantity(); 
  
  public void removeItem() throws InvalidAuctionStatusException; 

  /** 
   * Zadanie ponuky v otvorenej aukcii
   * 
   * @param bidAmount - hodnota ponuky
   * @param bidder - autor ponuky 
   * @return - automaticky priraden ID transakcie 
   * @throws InvalidBidException - ak ponuka naspa poadovan kritri
   * @throws InvalidAuctionStatusException - ak aukcia nie je prstupn
   */ 
  public String submitBid(double bidAmount, Bidder bidder) 
                    throws InvalidBidException, InvalidAuctionStatusException; 

  public double computeNextBidAmount() throws InvalidAuctionStatusException; 

  public BidView getLeadingBidView(); 

  public BidView getWinningBidView(); 

  public AuctionDetailView getAuctionDetail(); 

  /** 
   * Vrti as zostvajci do uzavretia aukcie 
   * 
   * @return - zostvajci as v ms
   */ 
  public long getTimeLeft(); 

  /** 
   * Zist i posledn ponuka dosiahla poadovan minimlnu hodnotu (rezervu)
   * 
   * @return - vrti true ak rezerva bola dosiahnut, alebo iadna rezerva  
   * nebola definovan a zrove bola dan aspo jedna ponuka
   */ 
  public boolean reserveMet(); 

  /** 
   * Po ukonen ozna posledn najvyiu ponuku za vaza aukcie, 
   * 
   * @throws InvalidAuctionStatusException - ak aukcia nebola otvoren
   */ 
  public void assignWinner() throws InvalidAuctionStatusException; 
}
